Gene Set Enrichment
===================

Enrich gene sets.

**Inputs**
- Data: Data set.
- Custom Gene Sets: Genes to compare.
- Reference Genes: Genes used as reference.

**Outputs**
- Matched Genes: Gene that match.


TODO Description.

![](images/gene_set_enrichment/Gene-Set-Enrichment-stamped.png)

1. Info
2. Custom Gene Set Term Column
3. Reference
4. Gene Sets
5. If *Commit Automatically* is ticked, results will be automatically sent to the output. Alternatively, press *Commit*.
6. Filtering.

Example
-------

TODO Example
